@@ -314,10 +314,12 @@ srv_t_crosstable <- function(id, data, reporter, filter_panel_api, label, x, y,
       selector_list = selector_list,
       merge_function = merge_function
     )
-    qenv <- teal.code::eval_code(data(), 'library("rtables");library("tern");library("dplyr")') # nolint quotes
+    qenv <- reactive(
+      teal.code::eval_code(data(), 'library("rtables");library("tern");library("dplyr")') # nolint quotes
+    )
     anl_merged_q <- reactive({
       req(anl_merged_input())
-      qenv %>%
+      qenv() %>%
         teal.code::eval_code(as.expression(anl_merged_input()$expr))
     })
 
